aboutsummaryrefslogtreecommitdiffstats
path: root/src/afb-wsj1.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/afb-wsj1.h')
-rw-r--r--src/afb-wsj1.h8
1 files changed, 3 insertions, 5 deletions
diff --git a/src/afb-wsj1.h b/src/afb-wsj1.h
index 7e318f6f..86c7cfdb 100644
--- a/src/afb-wsj1.h
+++ b/src/afb-wsj1.h
@@ -21,7 +21,7 @@ struct afb_wsj1;
struct afb_wsj1_msg;
struct json_object;
-struct sd_event;
+struct fdev;
/*
* Interface for callback functions.
@@ -48,13 +48,11 @@ struct afb_wsj1_itf {
};
/*
* Creates the afb_wsj1 socket connected to the file descriptor 'fd'
* and having the callback interface defined by 'itf' for the 'closure'.
- * When the creation is a success, the systemd event loop 'eloop' is
- * used for handling event for 'fd'.
* Returns the created wsj1 websocket or NULL in case of error.
*/
-extern struct afb_wsj1 *afb_wsj1_create(struct sd_event *eloop, int fd, struct afb_wsj1_itf *itf, void *closure);
+extern struct afb_wsj1 *afb_wsj1_create(struct fdev *fdev, struct afb_wsj1_itf *itf, void *closure);
/*
* Increases by one the count of reference to 'wsj1'
@@ -48,13 +48,11 @@ struct afb_wsj1_itf {
};
/*
- * Creates the afb_wsj1 socket connected to the file descriptor 'fd'
+ * Creates the afb_wsj1 socket connected to the file descriptor 'fdev'
* and having the callback interface defined by 'itf' for the 'closure'.